@@ -1,6 +1,8 @@
 """
 Contains some additional field types that are not included in Flask-RESTful.
 """
+import datetime
+from flask import current_app
 from flask.ext.restful.fields import *
 from werkzeug.utils import cached_property
 from flask_presst.references import Reference
@@ -22,7 +24,8 @@ class RelationshipFieldBase(Raw):
     def resource_class(self):
         if self._resource == 'self':
             return self.bound_resource
-        return self.bound_resource.api.get_resource_class(self._resource, self.bound_resource.__module__)
+        return current_app.presst.get_resource_class(self._resource,
+                                                     getattr(self.bound_resource, '__module__', None))
 
 
 class ToMany(RelationshipFieldBase):
@@ -49,17 +52,23 @@ class ToOne(RelationshipFieldBase):
 
 
 class Array(Raw):
-    pass
+    python_type = list
 
 
 class KeyValue(Raw):
-    pass
+    python_type = dict
 
 
 class JSON(Raw):
-    pass
+
+    @staticmethod
+    def python_type(value):
+        return value  # NOTE only works with request.json, not request.args.
 
 
 class Date(Raw):
+    python_type = datetime.date
+
     def format(self, value):
-        return value.strftime('%Y-%m-%d')
\ No newline at end of file
+        return value.strftime('%Y-%m-%d')
+
